@@ -1,6 +1,77 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="es_ES">
+<context>
+    <name>AccountDetailsDialog</name>
+    <message>
+        <location filename="../src/accountdetailsdialog.cpp" line="17"/>
+        <source>Account details</source>
+        <translation>Detalles de la cuenta</translation>
+    </message>
+    <message>
+        <location filename="../src/accountdetailsdialog.cpp" line="35"/>
+        <location filename="../src/accountdetailsdialog.cpp" line="74"/>
+        <source>Name</source>
+        <translation>Nombre</translation>
+    </message>
+    <message>
+        <location filename="../src/accountdetailsdialog.cpp" line="39"/>
+        <location filename="../src/accountdetailsdialog.cpp" line="76"/>
+        <source>Default budget</source>
+        <translation>Presupuesto por defecto</translation>
+    </message>
+    <message>
+        <location filename="../src/accountdetailsdialog.cpp" line="42"/>
+        <source>Select</source>
+        <translation>Seleccionar</translation>
+    </message>
+    <message>
+        <location filename="../src/accountdetailsdialog.cpp" line="44"/>
+        <location filename="../src/accountdetailsdialog.cpp" line="79"/>
+        <source>Save</source>
+        <translation>Guardar</translation>
+    </message>
+    <message>
+        <location filename="../src/accountdetailsdialog.cpp" line="46"/>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
+    <message>
+        <location filename="../src/accountdetailsdialog.cpp" line="61"/>
+        <source>Create new account</source>
+        <translation>Crear nueva cuenta</translation>
+    </message>
+    <message>
+        <location filename="../src/accountdetailsdialog.cpp" line="90"/>
+        <location filename="../src/accountdetailsdialog.cpp" line="126"/>
+        <source>Default budget cannot be empty</source>
+        <translation>El presupuesto no puede estar vacío</translation>
+    </message>
+    <message>
+        <location filename="../src/accountdetailsdialog.cpp" line="97"/>
+        <location filename="../src/accountdetailsdialog.cpp" line="133"/>
+        <source>Invalid budget format</source>
+        <translation>Formato del presupuesto inválido</translation>
+    </message>
+    <message>
+        <location filename="../src/accountdetailsdialog.cpp" line="121"/>
+        <source>Name field cannot be empty</source>
+        <translation>El campo nombre no puede estar vacío</translation>
+    </message>
+</context>
+<context>
+    <name>AccountsDialog</name>
+    <message>
+        <location filename="../src/accountsdialog.cpp" line="13"/>
+        <source>Accounts</source>
+        <translation>Cuentas</translation>
+    </message>
+    <message>
+        <location filename="../src/accountsdialog.cpp" line="27"/>
+        <source>New</source>
+        <translation>Nuevo</translation>
+    </message>
+</context>
 <context>
     <name>BudgetDialog</name>
     <message>
@@ -14,17 +85,12 @@
         <translation>Presupuesto mensual</translation>
     </message>
     <message>
-        <location filename="../src/budgetdialog.cpp" line="25"/>
-        <source>Set as default budget</source>
-        <translation>Guardar como presupuesto predeterminado</translation>
-    </message>
-    <message>
-        <location filename="../src/budgetdialog.cpp" line="29"/>
+        <location filename="../src/budgetdialog.cpp" line="26"/>
         <source>Save</source>
         <translation>Guardar</translation>
     </message>
     <message>
-        <location filename="../src/budgetdialog.cpp" line="42"/>
+        <location filename="../src/budgetdialog.cpp" line="39"/>
         <source>Invalid amount format</source>
         <translation>Formato inválido para cantidad</translation>
     </message>
@@ -32,52 +98,52 @@
 <context>
     <name>ConceptDetailsDialog</name>
     <message>
-        <location filename="../src/conceptdetailsdialog.cpp" line="16"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="17"/>
         <source>Item details</source>
         <translation>Detalles de concepto</translation>
     </message>
     <message>
-        <location filename="../src/conceptdetailsdialog.cpp" line="25"/>
-        <location filename="../src/conceptdetailsdialog.cpp" line="57"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="30"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="67"/>
         <source>Name</source>
         <translation>Nombre</translation>
     </message>
     <message>
-        <location filename="../src/conceptdetailsdialog.cpp" line="30"/>
-        <location filename="../src/conceptdetailsdialog.cpp" line="59"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="35"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="69"/>
         <source>Price</source>
         <translation>Precio</translation>
     </message>
     <message>
-        <location filename="../src/conceptdetailsdialog.cpp" line="33"/>
-        <location filename="../src/conceptdetailsdialog.cpp" line="62"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="38"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="72"/>
         <source>Save</source>
         <translation>Guardar</translation>
     </message>
     <message>
-        <location filename="../src/conceptdetailsdialog.cpp" line="35"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="40"/>
         <source>Delete</source>
         <translation>Eliminar</translation>
     </message>
     <message>
-        <location filename="../src/conceptdetailsdialog.cpp" line="49"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="54"/>
         <source>Create new item</source>
         <translation>Crear nuevo concepto</translation>
     </message>
     <message>
-        <location filename="../src/conceptdetailsdialog.cpp" line="73"/>
-        <location filename="../src/conceptdetailsdialog.cpp" line="103"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="83"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="113"/>
         <source>Price field cannot be empty</source>
         <translation>El campo precio no puede estar vacío</translation>
     </message>
     <message>
-        <location filename="../src/conceptdetailsdialog.cpp" line="80"/>
-        <location filename="../src/conceptdetailsdialog.cpp" line="110"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="90"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="120"/>
         <source>Invalid price format</source>
         <translation>Formato inválido para precio</translation>
     </message>
     <message>
-        <location filename="../src/conceptdetailsdialog.cpp" line="98"/>
+        <location filename="../src/conceptdetailsdialog.cpp" line="108"/>
         <source>Name field cannot be empty</source>
         <translation>El campo nombre no puede estar vacío</translation>
     </message>
@@ -124,83 +190,137 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../src/controller.cpp" line="77"/>
+        <location filename="../src/controller.cpp" line="39"/>
+        <source>You must create an account to be able to write down expenses</source>
+        <translation>Debe crear una cuenta para poder almacenar gastos</translation>
+    </message>
+    <message>
+        <location filename="../src/controller.cpp" line="47"/>
+        <source>There&apos;s no valid account selected</source>
+        <translation>No hay una cuenta válida seleccionada</translation>
+    </message>
+    <message>
+        <location filename="../src/controller.cpp" line="86"/>
+        <location filename="../src/controller.cpp" line="100"/>
+        <location filename="../src/controller.cpp" line="220"/>
+        <location filename="../src/controller.cpp" line="242"/>
+        <location filename="../src/controller.cpp" line="294"/>
+        <location filename="../src/controller.cpp" line="392"/>
+        <location filename="../src/controller.cpp" line="496"/>
+        <source>An account must be selected to perform this action</source>
+        <translation>Es necesaria una cuenta selecionada para poder realizar esta acción</translation>
+    </message>
+    <message>
+        <location filename="../src/controller.cpp" line="111"/>
         <source>Already at current month</source>
         <translation>Ya está en el mes actual</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="128"/>
+        <location filename="../src/controller.cpp" line="132"/>
+        <source>Error creating account</source>
+        <translation>Error creando cuenta</translation>
+    </message>
+    <message>
+        <location filename="../src/controller.cpp" line="135"/>
+        <source>Account already exists</source>
+        <translation>La cuenta ya existe</translation>
+    </message>
+    <message>
+        <location filename="../src/controller.cpp" line="167"/>
+        <source>Cannot delete active account</source>
+        <translation>No se puede borrar la cuenta activa</translation>
+    </message>
+    <message>
+        <location filename="../src/controller.cpp" line="172"/>
+        <source>When deleting an account, all the expenses associated to it will also be deleted
+Are you sure you want to delete the account?</source>
+        <translation>Al borrar una cuenta, los gastos asociados a ella
+        también serán borrados.
+¿Está seguro de querer borrar la cuenta?</translation>
+    </message>
+    <message>
+        <location filename="../src/controller.cpp" line="179"/>
+        <source>Error deleting account</source>
+        <translation>Error borrando la cuenta</translation>
+    </message>
+    <message>
+        <location filename="../src/controller.cpp" line="190"/>
+        <source>Error updating account</source>
+        <translation>Error actualizando la cuenta</translation>
+    </message>
+    <message>
+        <location filename="../src/controller.cpp" line="272"/>
         <source>Error deleting expense</source>
         <translation>Error eliminando gasto</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="139"/>
+        <location filename="../src/controller.cpp" line="283"/>
         <source>Error updating expense</source>
         <translation>Error actualizando gasto</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="206"/>
+        <location filename="../src/controller.cpp" line="351"/>
         <source>Error creating concept</source>
         <translation>Error creando concepto</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="209"/>
+        <location filename="../src/controller.cpp" line="354"/>
         <source>Concept already exists</source>
         <translation>El concepto ya existe</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="216"/>
+        <location filename="../src/controller.cpp" line="361"/>
         <source>When deleting a concept, all the expenses associated to it will be assigned an empty concept instead.
 Are you sure you want to delete the concept?</source>
         <translation>Al eliminar un concepto, a todos los gastos asociados a ese concepto se les asignará un concepto vacío en su lugar.
 ¿Está seguro de que desea eliminar el concepto?</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="225"/>
+        <location filename="../src/controller.cpp" line="370"/>
         <source>Error deleting concept</source>
         <translation>Error eliminando concepto</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="236"/>
+        <location filename="../src/controller.cpp" line="381"/>
         <source>Error updating concept</source>
         <translation>Error actualizando concepto</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="282"/>
+        <location filename="../src/controller.cpp" line="432"/>
         <source>Current month fits in the scheduled expense description.
 Do you want the expense to be created in it?</source>
         <translation>El mes actual cumple la descripción para el gasto planificado.
 ¿Desea que el gasto sea creado en él?</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="292"/>
+        <location filename="../src/controller.cpp" line="443"/>
         <source>Error creating scheduled expense</source>
         <translation>Error creando el gasto planificado</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="303"/>
+        <location filename="../src/controller.cpp" line="454"/>
         <source>Error deleting scheduled expense</source>
         <translation>Error eliminando gasto planificado</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="323"/>
+        <location filename="../src/controller.cpp" line="474"/>
         <source>Current month fits in the scheduled expense description after the modification.
 Do you want the expense to be created in it?</source>
         <translation>El mes actual cumple la descripción para el gasto planificado tras la modificación.
 ¿Desea que el gasto sea creado en él?</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="333"/>
+        <location filename="../src/controller.cpp" line="485"/>
         <source>Error updating scheduled expense</source>
         <translation>Error actualizando gasto planificado</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="353"/>
+        <location filename="../src/controller.cpp" line="510"/>
         <source>Error loading data interval</source>
         <translation>Error cargando datos de intervalo</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="363"/>
+        <location filename="../src/controller.cpp" line="520"/>
         <source>Error loading interval data</source>
         <translation>Error cargando datos de período</translation>
     </message>
@@ -246,27 +366,27 @@ Do you want the expense to be created in it?</source>
         <translation>Añadir nuevo gasto</translation>
     </message>
     <message>
-        <location filename="../src/expensedetailsdialog.cpp" line="84"/>
+        <location filename="../src/expensedetailsdialog.cpp" line="95"/>
         <source>Day</source>
         <translation>Día</translation>
     </message>
     <message>
-        <location filename="../src/expensedetailsdialog.cpp" line="91"/>
+        <location filename="../src/expensedetailsdialog.cpp" line="103"/>
         <source>Item</source>
         <translation>Concepto</translation>
     </message>
     <message>
-        <location filename="../src/expensedetailsdialog.cpp" line="102"/>
+        <location filename="../src/expensedetailsdialog.cpp" line="114"/>
         <source>Amount</source>
         <translation>Cantidad</translation>
     </message>
     <message>
-        <location filename="../src/expensedetailsdialog.cpp" line="105"/>
+        <location filename="../src/expensedetailsdialog.cpp" line="117"/>
         <source>Description</source>
         <translation>Descripción</translation>
     </message>
     <message>
-        <location filename="../src/expensedetailsdialog.cpp" line="111"/>
+        <location filename="../src/expensedetailsdialog.cpp" line="123"/>
         <source>Save</source>
         <translation>Guardar</translation>
     </message>
@@ -281,17 +401,32 @@ Do you want the expense to be created in it?</source>
         <translation>Eliminar</translation>
     </message>
     <message>
-        <location filename="../src/expensedetailsdialog.cpp" line="127"/>
+        <location filename="../src/expensedetailsdialog.cpp" line="139"/>
+        <source>Today</source>
+        <translation>Hoy</translation>
+    </message>
+    <message>
+        <location filename="../src/expensedetailsdialog.cpp" line="141"/>
+        <source>Yesterday</source>
+        <translation>Ayer</translation>
+    </message>
+    <message>
+        <location filename="../src/expensedetailsdialog.cpp" line="143"/>
+        <source>Tomorrow</source>
+        <translation>Mañana</translation>
+    </message>
+    <message>
+        <location filename="../src/expensedetailsdialog.cpp" line="163"/>
         <source>Invalid day</source>
         <translation>Día inválido</translation>
     </message>
     <message>
-        <location filename="../src/expensedetailsdialog.cpp" line="141"/>
+        <location filename="../src/expensedetailsdialog.cpp" line="177"/>
         <source>Choose a concept or enter a description</source>
         <translation>Seleccione un concepto o introduzca una descripción</translation>
     </message>
     <message>
-        <location filename="../src/expensedetailsdialog.cpp" line="147"/>
+        <location filename="../src/expensedetailsdialog.cpp" line="183"/>
         <source>Invalid amount</source>
         <translation>Cantidad inválida</translation>
     </message>
@@ -312,49 +447,64 @@ Do you want the expense to be created in it?</source>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/mainwindow.cpp" line="32"/>
-        <location filename="../src/mainwindow.cpp" line="51"/>
+        <location filename="../src/mainwindow.cpp" line="18"/>
+        <source>Account: none selected</source>
+        <translation>Cuenta: ninguna seleccionada</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="34"/>
+        <location filename="../src/mainwindow.cpp" line="55"/>
         <source>Budget</source>
         <translation>Presupuesto</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="36"/>
-        <location filename="../src/mainwindow.cpp" line="53"/>
+        <location filename="../src/mainwindow.cpp" line="38"/>
+        <location filename="../src/mainwindow.cpp" line="56"/>
         <source>Expenses</source>
         <translation>Gastos</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="40"/>
+        <location filename="../src/mainwindow.cpp" line="42"/>
         <source>Difference</source>
         <translation>Diferencia</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="46"/>
+        <location filename="../src/mainwindow.cpp" line="48"/>
         <source>Add expense</source>
         <translation>Nuevo gasto</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="52"/>
+        <location filename="../src/mainwindow.cpp" line="53"/>
+        <source>Accounts</source>
+        <translation>Cuentas</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="54"/>
         <source>Items</source>
         <translation>Conceptos</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="54"/>
+        <location filename="../src/mainwindow.cpp" line="57"/>
         <source>Scheduled</source>
         <translation>Planificados</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="55"/>
+        <location filename="../src/mainwindow.cpp" line="58"/>
         <source>Summary</source>
         <translation>Resumen</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="106"/>
+        <location filename="../src/mainwindow.cpp" line="94"/>
+        <source>Account: %1</source>
+        <translation>Cuenta: %1</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="125"/>
         <source>accumulated view</source>
         <translation>vista acumulada</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="108"/>
+        <location filename="../src/mainwindow.cpp" line="127"/>
         <source>daily view</source>
         <translation>vista diaria</translation>
     </message>
