@@ -22,9 +22,6 @@ BudgetDialog::BudgetDialog(double current,
         _budget = new QLineEdit(QString("%1").arg(current));
         form->addRow (new QLabel(tr("Month budget")), _budget);
 
-        _default = new QCheckBox(tr("Set as default budget"));
-        form->addRow(_default);
-
         QDialogButtonBox *box = new QDialogButtonBox (QDialogButtonBox::Cancel);
         QPushButton *saveButton = new QPushButton(tr("Save"));
         box->addButton(saveButton, QDialogButtonBox::ActionRole);
@@ -43,7 +40,7 @@ void BudgetDialog::changeBudget()
                 return;
         }
 
-        emit changeBudget(newBudget, _default->isChecked());
+        emit changeBudget(newBudget);
 
         accept();
 }
