@@ -14,6 +14,8 @@
 #include "confirmationdialog.h"
 #include "summarywindow.h"
 #include "datechooserdialog.h"
+#include "accountsdialog.h"
+#include "accountdetailsdialog.h"
 
 Controller::Controller()
 {
@@ -21,23 +23,48 @@ Controller::Controller()
         configFile.append(QDir::separator()).append(DATA_FOLDER);
         configFile.append(QDir::separator()).append(CONFIG_FILENAME);
 
-        settings = new QSettings (configFile, QSettings::NativeFormat);
+        settings = new QSettings (configFile, QSettings::NativeFormat, this);
+        concepts = new QStandardItemModel(0, 0, this);
+        accounts = new QStandardItemModel(0, 3, this);
+        scheduled = new QStandardItemModel(0, 7, this);
 
-        concepts = new QStandardItemModel(0,0);
         loadConcepts();
+        loadAccounts();
 
-        scheduled = new QStandardItemModel(0,7);
-        loadScheduled();
+        activeAccount = NULL;
+        month = NULL;
 
-        month = new MonthData(QDate::currentDate());
-        loadMonth();
+        if (accounts->rowCount() == 0) {
+                /* no accounts in the database */
+                QMaemo5InformationBox::information(&mainWindow, tr("You must create an account to be able to write down expenses"));
+        } else {
+                int activeAccountId = settings->value(ACTIVE_ACCOUNT_KEY, 0).toInt();
+                QList<QStandardItem*> list = accounts->findItems(QString("%1").arg(activeAccountId),
+                                                                 Qt::MatchFixedString,
+                                                                 0);
+                if (list.size() == 0) {
+                        /* can only happen if the account is manually deleted from the database */
+                        QMaemo5InformationBox::information(&mainWindow, tr("There's no valid account selected"));
+                } else {
+                        int row = list[0]->index().row();
+                        activeAccount = new Account(accounts->item(row, 0)->text().toInt(),
+                                                    accounts->item(row, 1)->text(),
+                                                    accounts->item(row, 2)->text().toDouble(),
+                                                    this);
+                        /* everything went fine. Load account dependant info */
+                        loadScheduled();
+                        month = new MonthData(QDate::currentDate(), activeAccount, this);
+                        loadMonth();
 
-        mainWindow.setMonthData(month);
+                        mainWindow.setMonthData(month);
+                }
+        }
 
         connect(&mainWindow, SIGNAL(previousMonth()), this, SLOT(previousMonth()));
         connect(&mainWindow, SIGNAL(nextMonth()), this, SLOT(nextMonth()));
         connect(&mainWindow, SIGNAL(addExpenseSelected()), this, SLOT(newExpenseSelected()));
         connect(&mainWindow, SIGNAL(budgetSelected()), this, SLOT(budgetSelected()));
+        connect(&mainWindow, SIGNAL(accountsSelected()), this, SLOT(accountsSelected()));
         connect(&mainWindow, SIGNAL(conceptsSelected()), this, SLOT(conceptsSelected()));
         connect(&mainWindow, SIGNAL(expensesSelected()), this, SLOT(expensesSelected()));
         connect(&mainWindow, SIGNAL(scheduledSelected()), this, SLOT(scheduledSelected()));
@@ -46,9 +73,6 @@ Controller::Controller()
 
 Controller::~Controller()
 {
-        delete month;
-        delete concepts;
-        delete settings;
 }
 
 void Controller::runApp()
@@ -58,8 +82,13 @@ void Controller::runApp()
 
 void Controller::previousMonth()
 {
+        if (!activeAccount) {
+                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                return;
+        }
+
         MonthData *old = month;
-        month = new MonthData(old->previous());
+        month = new MonthData(old->previous(), activeAccount, this);
         loadMonth();
         mainWindow.setMonthData(month);
         delete old;
@@ -67,9 +96,14 @@ void Controller::previousMonth()
 
 void Controller::nextMonth()
 {
+        if (!activeAccount) {
+                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                return;
+        }
+
         if (month->next() <= QDate::currentDate()) {
                 MonthData *old = month;
-                month = new MonthData(old->next());
+                month = new MonthData(old->next(), activeAccount, this);
                 loadMonth();
                 mainWindow.setMonthData(month);
                 delete old;
@@ -78,10 +112,115 @@ void Controller::nextMonth()
         }
 }
 
+/* ------------------ account dialog functions ---------------------*/
+
+void Controller::newAccountSelected()
+{
+        AccountDetailsDialog dialog(&mainWindow);
+
+        connect(&dialog, SIGNAL(newAccountConfirmed(Account*)), this, SLOT(newAccountConfirmed(Account*)));
+
+        dialog.exec();
+}
+
+void Controller::newAccountConfirmed(Account *a)
+{
+        if (!db.exists(a)) {
+                if (db.create(a)) {
+                        loadAccounts();
+                } else {
+                        QMaemo5InformationBox::information(&mainWindow, tr("Error creating account"));
+                }
+        } else {
+                QMaemo5InformationBox::information(&mainWindow, tr("Account already exists"));
+        }
+        delete a;
+}
+
+void Controller::accountsSelected()
+{
+        AccountsDialog dialog(accounts, &mainWindow);
+
+        connect(&dialog, SIGNAL(newAccountSelected()), this, SLOT(newAccountSelected()));
+        connect(&dialog, SIGNAL(accountDetailsSelected(QModelIndex)), this, SLOT(accountDetailsSelected(QModelIndex)));
+
+        dialog.exec();
+}
+
+void Controller::accountDetailsSelected(QModelIndex index)
+{
+        AccountDetailsDialog dialog(accounts, index.row(), &mainWindow);
+
+        connect(&dialog, SIGNAL(deleteAccountConfirmed(Account*)),
+                this, SLOT(deleteAccountConfirmed(Account*)));
+        connect(&dialog, SIGNAL(updateAccountConfirmed(Account*)),
+                this, SLOT(updateAccountConfirmed(Account*)));
+        connect(&dialog, SIGNAL(selectAccountConfirmed(Account*)),
+                this, SLOT(selectAccountConfirmed(Account*)));
+
+        dialog.exec();
+}
+
+void Controller::deleteAccountConfirmed(Account *a)
+{
+        if (a->id() == activeAccount->id()) {
+                QMaemo5InformationBox::information(&mainWindow, tr("Cannot delete active account"));
+                delete a;
+                return;
+        }
+
+        QString message(tr("When deleting an account, all the expenses associated to it "
+                           "will also be deleted\n"
+                           "Are you sure you want to delete the account?"));
+        if (ConfirmationDialog::askConfirmation(message)) {
+                if (db.remove(a)) {
+                        loadAccounts();
+                } else {
+                        QMaemo5InformationBox::information(&mainWindow, tr("Error deleting account"));
+                }
+        }
+        delete a;
+}
+
+void Controller::updateAccountConfirmed(Account *a)
+{
+        if (db.update(a)) {
+                loadAccounts();
+        } else {
+                QMaemo5InformationBox::information(&mainWindow, tr("Error updating account"));
+        }
+
+        delete a;
+}
+
+void Controller::selectAccountConfirmed(Account *a)
+{
+        if (activeAccount != NULL) {
+                delete activeAccount;
+        }
+        activeAccount = a;
+        activeAccount->setParent(this);
+        settings->setValue(ACTIVE_ACCOUNT_KEY, a->id());
+        loadScheduled();
+
+        if (month != NULL) {
+                delete month;
+        }
+        month = new MonthData(QDate::currentDate(), activeAccount, this);
+        loadMonth();
+        mainWindow.setMonthData(month);
+}
+
+
 /* ------------------ add expense dialog functions ---------------------*/
 
 void Controller::newExpenseSelected()
 {
+        if (!activeAccount) {
+                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                return;
+        }
+
         ExpenseDetailsDialog dialog(month->date(), concepts, (QWidget*)QObject::sender());
 
         connect(&dialog, SIGNAL(newExpenseConfirmed(Expense*)), this, SLOT(newExpenseConfirmed(Expense*)));
@@ -91,7 +230,7 @@ void Controller::newExpenseSelected()
 
 void Controller::newExpenseConfirmed(Expense *e)
 {
-        if (db.create(month->year(), month->month(), e)) {
+        if (db.create(month->year(), month->month(), activeAccount->id(),  e)) {
                 loadMonth(true);
         }
         delete e;
@@ -99,6 +238,11 @@ void Controller::newExpenseConfirmed(Expense *e)
 
 void Controller::expensesSelected()
 {
+        if (!activeAccount) {
+                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                return;
+        }
+
         ExpensesList *list = new ExpensesList (month->expenses(), &mainWindow);
 
         connect(list, SIGNAL(newExpenseSelected()), this, SLOT(newExpenseSelected()));
@@ -146,22 +290,23 @@ void Controller::updateExpenseConfirmed(Expense *e)
 
 void Controller::budgetSelected()
 {
+        if (!activeAccount) {
+                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                return;
+        }
+
         BudgetDialog dialog(month->budget(), &mainWindow);
 
-        connect(&dialog, SIGNAL(changeBudget(double, bool)), this, SLOT(changeBudgetConfirmed(double, bool)));
+        connect(&dialog, SIGNAL(changeBudget(double)), this, SLOT(changeBudgetConfirmed(double)));
 
         dialog.exec();
 }
 
-void Controller::changeBudgetConfirmed (double budget, bool setDefault)
+void Controller::changeBudgetConfirmed (double budget)
 {
-        if (db.updateBudget(month->year(), month->month(), budget)) {
+        if (db.updateBudget(month->year(), month->month(), activeAccount->id(), budget)) {
                 month->setBudget(budget);
         }
-
-        if (setDefault) {
-                settings->setValue (DEFAULT_BUDGET_KEY, budget);
-        }
 }
 
 /* ------------------ concept management dialog functions ---------------------*/
@@ -243,6 +388,11 @@ void Controller::updateConceptConfirmed(Concept *c)
 
 void Controller::scheduledSelected()
 {
+        if (!activeAccount) {
+                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                return;
+        }
+
         ScheduledList *list = new ScheduledList (scheduled, &mainWindow);
 
         connect(list, SIGNAL(newScheduledSelected()), this, SLOT(newScheduledSelected()));
@@ -274,7 +424,7 @@ void Controller::scheduledDetailsSelected(QModelIndex index)
 
 void Controller::newScheduledConfirmed(Expense *e)
 {
-        if (db.createScheduled(e)) {
+        if (db.createScheduled(activeAccount->id(), e)) {
                 loadScheduled();
                 if (e->frecuency() & (1 << QDate::currentDate().month() -1)) {
                         /* current month fits into the just created scheduled expense. Ask the user
@@ -283,7 +433,8 @@ void Controller::newScheduledConfirmed(Expense *e)
                                            "Do you want the expense to be created in it?"));
                         if (ConfirmationDialog::askConfirmation(message)) {
                                 Expense *newExpense = new Expense (0, e->day(), e->amount(), e->concept(), e->description());
-                                db.create(QDate::currentDate().year(), QDate::currentDate().month(), newExpense);
+                                db.create(QDate::currentDate().year(), QDate::currentDate().month(),
+                                          activeAccount->id(), newExpense);
                                 loadMonth(true);
                                 delete newExpense;
                         }
@@ -324,7 +475,8 @@ void Controller::updateScheduledConfirmed(Expense *e)
                                            "Do you want the expense to be created in it?"));
                         if (ConfirmationDialog::askConfirmation(message)) {
                                 Expense *newExpense = new Expense (0, e->day(), e->amount(), e->concept(), e->description());
-                                db.create(QDate::currentDate().year(), QDate::currentDate().month(), newExpense);
+                                db.create(QDate::currentDate().year(), QDate::currentDate().month(),
+                                          activeAccount->id(), newExpense);
                                 loadMonth(true);
                                 delete newExpense;
                         }
@@ -340,9 +492,14 @@ void Controller::updateScheduledConfirmed(Expense *e)
 
 void Controller::summarySelected()
 {
+        if (!activeAccount) {
+                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                return;
+        }
+
         int minYear, minMonth, maxYear, maxMonth;
 
-        if (db.getDataInterval(minYear, minMonth, maxYear, maxMonth)) {
+        if (db.getDataInterval(activeAccount->id(), minYear, minMonth, maxYear, maxMonth)) {
                 summaryWindow = new SummaryWindow(minYear, minMonth, maxYear, maxMonth, &mainWindow);
 
                 connect (summaryWindow, SIGNAL(periodChanged(int, int, int, int)),
@@ -357,7 +514,7 @@ void Controller::summarySelected()
 void Controller::summaryPeriodChanged(int startYear, int startMonth, int endYear, int endMonth)
 {
         SummaryData *data = new SummaryData(startYear, startMonth, endYear, endMonth);
-        if (db.load(data)) {
+        if (db.load(activeAccount->id(), data)) {
                 summaryWindow->setSummaryData(data);
         } else {
                 QMaemo5InformationBox::information(&mainWindow, tr("Error loading interval data"));
@@ -376,7 +533,6 @@ void Controller::loadMonth(bool reload)
                 if (db.exists(month)) {
                         db.load (month, false);
                 } else {
-                        month->setBudget (settings->value(DEFAULT_BUDGET_KEY, DEFAULT_BUDGET).toDouble());
                         db.create(month);
                         /* create scheduled expenses in new month, but only if it is the current one */
                         if (month->isCurrent()) {
@@ -393,7 +549,7 @@ void Controller::loadMonth(bool reload)
                                                                                  scheduled->item(i, 2)->text().toDouble(),
                                                                                  scheduled->item(i, 3)->text(),
                                                                                  scheduled->item(i, 4)->text());
-                                                        db.create(month->year(), month->month(), e);
+                                                        db.create(month->year(), month->month(), activeAccount->id(), e);
                                                         delete e;
                                                 }
                                         }
@@ -413,5 +569,11 @@ void Controller::loadConcepts()
 void Controller::loadScheduled()
 {
         scheduled->removeRows(0, scheduled->rowCount());
-        db.loadScheduled(scheduled);
+        db.loadScheduled(activeAccount->id(), scheduled);
+}
+
+void Controller::loadAccounts()
+{
+        accounts->removeRows(0, accounts->rowCount());
+        db.loadAccounts(accounts);
 }
