@@ -4,6 +4,7 @@
 #include <QSqlQuery>
 #include <QVariant>
 #include <QStandardItem>
+#include <QUuid>
 
 
 DBManager::DBManager()
@@ -50,10 +51,21 @@ bool DBManager::createTables()
         bool ret;
         QSqlQuery query;
 
+        ret = query.exec("create table account ("
+                         "id integer primary key autoincrement, "
+                         "name text unique not null, "
+                         "budget real, "
+                         "password text)");
+
+        if (!ret) {
+                qDebug() << "\nError creating table account" << query.lastError();
+        }
+
         ret = query.exec("create table month (year integer not null, "
                          "month integer not null, "
+                         "account integer references account(id), "
                          "budget real not null, "
-                         "primary key (year,month))");
+                         "primary key (year,month,account))");
         if (!ret) {
                 qDebug() << "\nError creating table month" << query.lastError();
                 return false;
@@ -70,17 +82,20 @@ bool DBManager::createTables()
         ret = query.exec("create table expense (id integer primary key autoincrement,"
                          "year integer, "
                          "month integer, "
-                         "day integer, "
+                         "account integer, "
+                         "day integer not null, "
                          "amount real not null, "
                          "concept text references concept(name), "
                          "description text, "
-                         "foreign key (year,month) references month(year,month))");
+                         "uuid text, "
+                         "foreign key (year,month,account) references month(year,month,account))");
 
         if (!ret) {
                 qDebug() << "\nError creating table expense" << query.lastError();
         }
 
         ret = query.exec("create table scheduled (id integer primary key autoincrement,"
+                         "account integer references account(id), "
                          "day integer, "
                          "amount real not null, "
                          "concept text references concept(name), "
@@ -94,6 +109,150 @@ bool DBManager::createTables()
         return ret;
 }
 
+/*----------- Account operations -------------*/
+
+bool DBManager::create(Account *a)
+{
+        bool ret;
+        QSqlQuery query;
+
+        ret = query.exec(QString ("insert into account (id,name,budget) "
+                                  "values (NULL,'%1', %2)")
+                         .arg(a->name())
+                         .arg(a->budget()));
+
+        if (!ret) {
+                qDebug() << "\nError adding account to the database" << query.lastError();
+        }
+        return ret;
+}
+
+bool DBManager::loadAccounts(QStandardItemModel *accounts)
+{
+        bool ret;
+        QSqlQuery query;
+
+        ret = query.exec(QString ("select id,name,budget from account order by name collate nocase"));
+
+        if (!ret) {
+                qDebug() << "\nError loading accounts from database" << query.lastError();
+                return ret;
+        }
+
+        while (query.next()) {
+                QList<QStandardItem*> row;
+                QStandardItem *item;
+                item = new QStandardItem (query.value(0).toString());
+                item->setTextAlignment(Qt::AlignCenter);
+                item->setEditable(false);
+                row.append(item);
+                item = new QStandardItem (query.value(1).toString());
+                item->setTextAlignment(Qt::AlignCenter);
+                item->setEditable(false);
+                row.append(item);
+                item = new QStandardItem (query.value(2).toString());
+                item->setTextAlignment(Qt::AlignCenter);
+                item->setEditable(false);
+                row.append(item);
+                accounts->appendRow(row);
+        }
+
+        return true;
+}
+
+bool DBManager::update(Account *a)
+{
+        bool ret;
+        QSqlQuery query;
+
+        ret = query.exec(QString ("update account set budget=%1 where id=%2")
+                         .arg(a->budget())
+                         .arg(a->id()));
+
+        if (!ret) {
+                qDebug() << "\nError updating account in database" << query.lastError();
+        }
+        return ret;
+}
+
+bool DBManager::remove(Account *a)
+{
+        bool ret;
+        QSqlQuery query;
+
+        ret = query.exec(QString ("delete from scheduled where account=%1")
+                         .arg(a->id()));
+
+        if (!ret) {
+                qDebug() << "\nError deleting account related scheduled from database" << query.lastError();
+                return ret;
+        }
+
+        ret = query.exec(QString ("delete from expense where account=%1")
+                         .arg(a->id()));
+
+        if (!ret) {
+                qDebug() << "\nError deleting account related expenses from database" << query.lastError();
+                return ret;
+        }
+
+        ret = query.exec(QString ("delete from month where account=%1")
+                         .arg(a->id()));
+
+        if (!ret) {
+                qDebug() << "\nError deleting account related months from database" << query.lastError();
+                return ret;
+        }
+
+        ret = query.exec(QString ("delete from account where id=%1")
+                         .arg(a->id()));
+
+        if (!ret) {
+                qDebug() << "\nError deleting account from database" << query.lastError();
+                return ret;
+        }
+
+        return ret;
+}
+
+bool DBManager::exists(Account *a)
+{
+        bool ret;
+        QSqlQuery query;
+
+        ret = query.exec(QString ("select * from account where name='%1'")
+                         .arg(a->name()));
+        if (!ret) {
+                qDebug() << "\nError accessing database" << query.lastError();
+                return ret;
+        }
+
+        return query.next();
+}
+
+bool DBManager::load(Account *a)
+{
+        bool ret;
+        QSqlQuery query;
+
+        ret = query.exec(QString ("select name, budget from account where id=%1")
+                         .arg(a->id()));
+        if (!ret) {
+                qDebug() << "\nError accessing database" << query.lastError();
+                return ret;
+        }
+
+        if (!query.next()) {
+                qDebug() << "Error: active account doesn't exist in database";
+                return false;
+        }
+
+        a->setName(query.value(0).toString());
+        a->setBudget(query.value(1).toDouble());
+        return true;
+}
+
+
 /*----------- MonthData operations -------------*/
 
 bool DBManager::create(MonthData *month)
@@ -101,10 +260,11 @@ bool DBManager::create(MonthData *month)
         bool ret;
         QSqlQuery query;
 
-        ret = query.exec (QString("insert into month (year, month, budget) "
-                                  "values (%1, %2, %3)")
+        ret = query.exec (QString("insert into month (year, month, account, budget) "
+                                  "values (%1, %2, %3, %4)")
                           .arg(month->year())
                           .arg(month->month())
+                          .arg(month->account()->id())
                           .arg(month->budget()));
 
         if (!ret) {
@@ -119,9 +279,10 @@ bool DBManager::load(MonthData *month, bool expensesOnly)
         QSqlQuery query;
 
         if (!expensesOnly) {
-                ret = query.exec(QString ("select budget from month where year=%1 and month=%2")
+                ret = query.exec(QString ("select budget from month where year=%1 and month=%2 and account=%3")
                                  .arg(month->year())
-                                 .arg(month->month()));
+                                 .arg(month->month())
+                                 .arg(month->account()->id()));
                 if (!ret) {
                         qDebug() << "\nError loading month budget from database" << query.lastError();
                         return ret;
@@ -136,9 +297,10 @@ bool DBManager::load(MonthData *month, bool expensesOnly)
         }
 
         ret = query.exec(QString ("select id, day, amount, concept, description from expense "
-                                  "where year=%1 and month=%2 order by day")
+                                  "where year=%1 and month=%2 and account=%3 order by day")
                          .arg(month->year())
-                         .arg(month->month()));
+                         .arg(month->month())
+                         .arg(month->account()->id()));
 
         if (!ret) {
                 qDebug() << "\nError loading month expenses from database" << query.lastError();
@@ -161,9 +323,10 @@ bool DBManager::exists(MonthData *month)
         bool ret;
         QSqlQuery query;
 
-        ret = query.exec(QString ("select * from month where year=%1 and month=%2")
+        ret = query.exec(QString ("select * from month where year=%1 and month=%2 and account=%3")
                          .arg(month->year())
-                         .arg(month->month()));
+                         .arg(month->month())
+                         .arg(month->account()->id()));
         if (!ret) {
                 qDebug() << "\nError accessing database" << query.lastError();
                 return ret;
@@ -174,19 +337,21 @@ bool DBManager::exists(MonthData *month)
 
 /*----------- Expense operations -------------*/
 
-bool DBManager::create(int year, int month, Expense *e)
+bool DBManager::create(int year, int month, int account, Expense *e)
 {
         bool ret;
         QSqlQuery query;
 
-        ret = query.exec(QString ("insert into expense (id, year, month, day, amount, concept, description) "
-                                  "values (NULL, %1, %2, %3, %4, '%5', '%6')")
+        ret = query.exec(QString ("insert into expense (id, year, month, account, day, amount, concept, description, uuid) "
+                                  "values (NULL, %1, %2, %3, %4, %5, '%6', '%7', '%8')")
                          .arg(year)
                          .arg(month)
+                         .arg(account)
                          .arg(e->day())
                          .arg(e->amount())
                          .arg(e->concept())
-                         .arg(e->description()));
+                         .arg(e->description())
+                         .arg(QUuid::createUuid().toString()));
 
         if (!ret) {
                 qDebug() << "\nError adding expense to the database" << query.lastError();
@@ -338,15 +503,16 @@ bool DBManager::exists(Concept *c)
 
 /*----------- Budget operations -------------*/
 
-bool DBManager::updateBudget(int year, int month, double budget)
+bool DBManager::updateBudget(int year, int month, int account, double budget)
 {
         bool ret;
         QSqlQuery query;
 
-        ret = query.exec(QString ("update month set budget=%1 where year=%2 and month=%3")
+        ret = query.exec(QString ("update month set budget=%1 where year=%2 and month=%3 and account=%4")
                          .arg(budget)
                          .arg(year)
-                         .arg(month));
+                         .arg(month)
+                         .arg(account));
         if (!ret) {
                 qDebug() << "\nError saving month budget to database" << query.lastError();
                 return ret;
@@ -357,13 +523,14 @@ bool DBManager::updateBudget(int year, int month, double budget)
 
 /*----------- Scheduled expense operations -------------*/
 
-bool DBManager::createScheduled(Expense *e)
+bool DBManager::createScheduled(int account, Expense *e)
 {
         bool ret;
         QSqlQuery query;
 
-        ret = query.exec(QString ("insert into scheduled (id, day, amount, concept, description, frecuency) "
-                                  "values (NULL, %1, %2, '%3', '%4', %5)")
+        ret = query.exec(QString ("insert into scheduled (id, account, day, amount, concept, description, frecuency) "
+                                  "values (NULL, %1, %2, %3, '%4', '%5', %6)")
+                         .arg(account)
                          .arg(e->day())
                          .arg(e->amount())
                          .arg(e->concept())
@@ -392,13 +559,14 @@ bool DBManager::removeScheduled(Expense *e)
         return ret;
 }
 
-bool DBManager::loadScheduled(QStandardItemModel *scheduled)
+bool DBManager::loadScheduled(int account, QStandardItemModel *scheduled)
 {
         bool ret;
         QSqlQuery query;
 
         ret = query.exec(QString ("select id,day,amount,concept,description,frecuency "
-                                  "from scheduled order by day"));
+                                  "from scheduled where account=%1 order by day")
+                         .arg(account));
 
         if (!ret) {
                 qDebug() << "\nError loading scheduled expenses from database" << query.lastError();
@@ -464,12 +632,13 @@ bool DBManager::updateScheduled(Expense *e)
 
 /*---------------- summary related functions ---------------*/
 
-bool DBManager::getDataInterval(int &minYear, int &minMonth, int &maxYear, int &maxMonth)
+bool DBManager::getDataInterval(int account, int &minYear, int &minMonth, int &maxYear, int &maxMonth)
 {
         bool ret;
         QSqlQuery query;
 
-        ret = query.exec(QString ("select year, month from month order by year, month limit 0,1"));
+        ret = query.exec(QString ("select year, month from month where account=%1 order by year, month limit 0,1")
+                         .arg(account));
         if (!ret) {
                 qDebug() << "\nError accessing database" << query.lastError();
                 return ret;
@@ -483,7 +652,8 @@ bool DBManager::getDataInterval(int &minYear, int &minMonth, int &maxYear, int &
                 return false;
         }
 
-        ret = query.exec(QString ("select year, month from month order by year desc , month desc limit 0,1"));
+        ret = query.exec(QString ("select year, month from month where account=%1 order by year desc , month desc limit 0,1")
+                         .arg(account));
         if (!ret) {
                 qDebug() << "\nError accessing database" << query.lastError();
                 return ret;
@@ -499,20 +669,37 @@ bool DBManager::getDataInterval(int &minYear, int &minMonth, int &maxYear, int &
         return true;
 }
 
-bool DBManager::load(SummaryData *summary)
+bool DBManager::load(int account, SummaryData *summary)
 {
         bool ret;
         QSqlQuery query;
 
-        ret = query.exec(QString ("select month.budget,sum(amount) from month left outer join expense "
-                                  "on (month.year=expense.year and month.month=expense.month) "
-                                  "group by month.year,month.month "
-                                  "having (month.year=%1 and month.month>=%2) or (month.year>%1 and month.year<%3) "
-                                  "or (month.year=%3 and month.month<=%4)")
-                         .arg(summary->startYear())
-                         .arg(summary->startMonth())
-                         .arg(summary->endYear())
-                         .arg(summary->endMonth()));
+        if (summary->startYear() == summary->endYear()) {
+                ret = query.exec(QString ("select month.budget,sum(amount) from month left outer join expense "
+                                          "on (month.year=expense.year and month.month=expense.month "
+                                          "and month.account=expense.account) "
+                                          "where month.account=%4 "
+                                          "group by month.year,month.month,month.account "
+                                          "having (month.year=%1 and month.month>=%2 and month.month<=%3)")
+                                 .arg(summary->startYear())
+                                 .arg(summary->startMonth())
+                                 .arg(summary->endMonth())
+                                 .arg(account));
+        } else {
+                ret = query.exec(QString ("select month.budget,sum(amount) from month left outer join expense "
+                                          "on (month.year=expense.year and month.month=expense.month "
+                                          "and month.account=expense.account) "
+                                          "where month.account=%5 "
+                                          "group by month.year,month.month,month.account "
+                                          "having (month.year=%1 and month.month>=%2) or (month.year>%1 and month.year<%3) "
+                                          "or (month.year=%3 and month.month<=%4)")
+                                 .arg(summary->startYear())
+                                 .arg(summary->startMonth())
+                                 .arg(summary->endYear())
+                                 .arg(summary->endMonth())
+                                 .arg(account));
+        }
+
         if (!ret) {
                 qDebug() << "\nError accessing database" << query.lastError();
                 return ret;
@@ -523,15 +710,29 @@ bool DBManager::load(SummaryData *summary)
                                       query.value(1).toDouble());
         }
 
-        ret = query.exec(QString ("select concept,sum(amount) from expense "
-                                  "where (year=%1 and month>=%2) "
-                                  "or (year>%1 and year<%3) "
-                                  "or (year=%3 and month<=%4)"
-                                  "group by concept order by concept collate nocase")
-                         .arg(summary->startYear())
-                         .arg(summary->startMonth())
-                         .arg(summary->endYear())
-                         .arg(summary->endMonth()));
+        if (summary->startYear() == summary->endYear()) {
+                ret = query.exec(QString ("select concept,sum(amount) from expense "
+                                          "where ((year=%1 and month>=%2 and month<=%3)) "
+                                          "and account=%4 "
+                                          "group by concept order by concept collate nocase")
+                                 .arg(summary->startYear())
+                                 .arg(summary->startMonth())
+                                 .arg(summary->endMonth())
+                                 .arg(account));
+        } else {
+                ret = query.exec(QString ("select concept,sum(amount) from expense "
+                                          "where ((year=%1 and month>=%2) "
+                                          "or (year>%1 and year<%3) "
+                                          "or (year=%3 and month<=%4)) "
+                                          "and account=%5 "
+                                          "group by concept order by concept collate nocase")
+                                 .arg(summary->startYear())
+                                 .arg(summary->startMonth())
+                                 .arg(summary->endYear())
+                                 .arg(summary->endMonth())
+                                 .arg(account));
+        }
+
         if (!ret) {
                 qDebug() << "\nError accessing database" << query.lastError();
                 return ret;
