@@ -6,5 +6,4 @@
 
 #define ORGANIZATION_NAME "Igalia"
 
-#define DEFAULT_BUDGET_KEY "defaultBudget"
-#define DEFAULT_BUDGET 1000
+#define ACTIVE_ACCOUNT_KEY "activeAccount"
