@@ -11,10 +11,14 @@ MainWindow::MainWindow(QWidget *parent)
         : QWidget(parent)
 {
         pressXPosition = 0;
+        month = NULL;
+
         setAttribute(Qt::WA_Maemo5StackedWindow);
 
         QVBoxLayout *vBox = new QVBoxLayout(this);
 
+        setWindowTitle(tr("Account: none selected"));
+
         dateLabel = new QLabel("");
         vBox->addWidget(dateLabel, 0, Qt::AlignCenter);
 
@@ -48,11 +52,17 @@ MainWindow::MainWindow(QWidget *parent)
         connect (button2, SIGNAL(clicked()), this, SIGNAL(addExpenseSelected()));
 
         QMenuBar *menubar = new QMenuBar(this);
-        menubar->addAction(tr("Budget"), this, SIGNAL(budgetSelected()));
+        menubar->addAction(tr("Accounts"), this, SIGNAL(accountsSelected()));
         menubar->addAction(tr("Items"), this, SIGNAL(conceptsSelected()));
-        menubar->addAction(tr("Expenses"), this, SIGNAL(expensesSelected()));
-        menubar->addAction(tr("Scheduled"), this, SIGNAL(scheduledSelected()));
-        menubar->addAction(tr("Summary"), this, SIGNAL(summarySelected()));
+        budgetAction = menubar->addAction(tr("Budget"), this, SIGNAL(budgetSelected()));
+        expensesAction = menubar->addAction(tr("Expenses"), this, SIGNAL(expensesSelected()));
+        scheduledAction = menubar->addAction(tr("Scheduled"), this, SIGNAL(scheduledSelected()));
+        summaryAction = menubar->addAction(tr("Summary"), this, SIGNAL(summarySelected()));
+
+        budgetAction->setEnabled(false);
+        expensesAction->setEnabled(false);
+        scheduledAction->setEnabled(false);
+        summaryAction->setEnabled(false);
 }
 
 QSize MainWindow::minimumSizeHint() const
@@ -74,6 +84,16 @@ void MainWindow::setMonthData(MonthData *data)
         connect(month, SIGNAL(budgetChanged()), this, SLOT(budgetChanged()));
 
         updateAll();
+
+        budgetAction->setEnabled(true);
+        expensesAction->setEnabled(true);
+        scheduledAction->setEnabled(true);
+        summaryAction->setEnabled(true);
+}
+
+void MainWindow::updateAccountLabel()
+{
+        setWindowTitle(tr("Account: %1").arg(month->account()->name()));
 }
 
 void MainWindow::expensesChanged()
@@ -92,6 +112,7 @@ void MainWindow::budgetChanged()
 
 void MainWindow::updateAll()
 {
+        updateAccountLabel();
         updateDateLabel();
         updateBudgetLabel();
         updateTotalLabel();
@@ -152,7 +173,9 @@ void MainWindow::mouseReleaseEvent(QMouseEvent *event)
                         emit nextMonth();
                 }
         } else {
-                graph->changeView();
-                updateDateLabel();
+                if (month != NULL) {
+                        graph->changeView();
+                        updateDateLabel();
+                }
         }
 }
