@@ -6,6 +6,7 @@
 #include <QPushButton>
 #include <QLabel>
 #include <QMouseEvent>
+#include <QAction>
 #include "monthdata.h"
 #include "expensesgraph.h"
 
@@ -28,6 +29,7 @@ class MainWindow : public QWidget
         void previousMonth();
         void nextMonth();
         void addExpenseSelected();
+        void accountsSelected();
         void budgetSelected();
         void conceptsSelected();
         void expensesSelected();
@@ -45,6 +47,7 @@ class MainWindow : public QWidget
         void updateTotalLabel();
         void updateSavedLabel();
         void updateGraph();
+        void updateAccountLabel();
 
         MonthData *month;
         ExpensesGraph *graph;
@@ -53,5 +56,9 @@ class MainWindow : public QWidget
         QLabel *totalLabel;
         QLabel *savedLabel;
         int pressXPosition;
+        QAction *budgetAction;
+        QAction *expensesAction;
+        QAction *scheduledAction;
+        QAction *summaryAction;
 };
 #endif
