@@ -9,18 +9,21 @@
 #include <QDebug>
 #include "expense.h"
 #include "global.h"
+#include "account.h"
 
 class MonthData : public QObject
 {
         Q_OBJECT
  public:
         MonthData(QDate date,
-                  double budget = DEFAULT_BUDGET);
+                  Account *account,
+                  QObject *parent = 0);
         ~MonthData();
 
         int year();
         int month();
         int days();
+        Account* account();
         double budget();
         void setBudget(double budget);
         void addExpense(Expense *e);
@@ -42,6 +45,7 @@ class MonthData : public QObject
 
         QDate _date;
         double _budget;
+        Account *_account;
         QVector<double> _summary;
         QStandardItemModel *_expenses;
         double _maxExpense;
